@@ -1,7 +1,7 @@
 BioCyc2cName <-
 function(parsed_MetaCyc.c, eq) {
   h.name = hash()
-  .set(h.name, keys = parsed_MetaCyc.c[,'BioCyc'], values = parsed_MetaCyc.c[,'name'])
+  h.name[parsed_MetaCyc.c[,'BioCyc']] = parsed_MetaCyc.c[,'name']
   result = conv(eq, h.name)
   
   return(result)
