@@ -2,7 +2,7 @@ Rhea2KEGG <-
 function(parsed_ChEBI, eq) {
   h.KEGG = hash()
   ind = grep('^$', parsed_ChEBI[,'KEGG'])
-  .set(h.KEGG, keys = parsed_ChEBI[-ind,'ChEBI'], values = parsed_ChEBI[-ind,'KEGG'])
+  h.KEGG[parsed_ChEBI[-ind,'ChEBI']] = parsed_ChEBI[-ind,'KEGG']
   result = conv(eq, h.KEGG)
   
   return(result)
