@@ -1,7 +1,7 @@
 Rhea2cName <-
 function(parsed_ChEBI, eq) {
   h.name = hash()
-  .set(h.name, keys = parsed_ChEBI[,'ChEBI'], values = parsed_ChEBI[,'name'])
+  h.name[parsed_ChEBI[,'ChEBI']] = parsed_ChEBI[,'name']
   result = conv(eq, h.name)
   
   return(result)
